@@ -1,7 +1,7 @@
 `growth2vgc.fnc` <-
 function(growth) {
-  require(zipfR, quietly = TRUE)
-  return(vgc(N  = growth@data$data$Tokens, 
+  requireNamespace("zipfR", quietly = TRUE)
+  return(zipfR::vgc(N  = growth@data$data$Tokens, 
              V  = growth@data$data$Types, 
              Vm = list(growth@data$data$HapaxLegomena,
                         growth@data$data$DisLegomena, 
